@@ -40,7 +40,7 @@ class TaoBaoProvider(BaseProvider):
 
     def query(self, ip):
         ret = copy(self.ret)
-        result = TaoBaoProvider.get_ip2location(ip, timeout=self.timeout)
+        result = TaoBaoProvider.get_location(ip, timeout=self.timeout)
         ret['query_time'] = get_current_time()
         if not result.get('error') and result.get('code') == 0:
             ret['status'] = 0
